==> yin_webview-0.0.1.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:yin_webview/YinWebViewPlugin.dart';
import 'dart:async';

import 'package:yin_webview/yin_webview.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Webview',
      theme: new ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: new MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => new _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  String url = "https://m.debug.8591.com.hk/mall/detail/4000553";

  ///内容视图
  Widget contentView() {
    List<Map<String, String>> cookies = new List();
    cookies.add({"k": "hkroles_develop", "v": "buyer%2Cseller%2Ccardseller"});
    cookies.add({"k": "hkuid_develop", "v": "1010004"});
    cookies.add({
      "k": "access_token_develop",
      "v":
          "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsImp0aSI6IjNlNjFiYjZiZDQ3YTZjNWE0M2VkZTEwMjUwZGU5ODE5N2U2NmM2ZTY1NGNlODI1MDEyYjIwMTU2ZjQ4YzY4MGNjZDg0NGNiNWQyNzA5NjAwIn0.eyJhdWQiOiIyIiwianRpIjoiM2U2MWJiNmJkNDdhNmM1YTQzZWRlMTAyNTBkZTk4MTk3ZTY2YzZlNjU0Y2U4MjUwMTJiMjAxNTZmNDhjNjgwY2NkODQ0Y2I1ZDI3MDk2MDAiLCJpYXQiOjE1NTgyNzQ2MzUsIm5iZiI6MTU1ODI3NDYzNSwiZXhwIjoxNTU4MzYxMDM0LCJzdWIiOiIxMDEwMDA0Iiwic2NvcGVzIjpbIioiXX0.Qf6cNTN_FkZG1KpBA76qZAwsqKMnFMNfSzoErmVm7b3pRh87J6Z2cPzO3NQy29k7g96RTPskDZbnLdM5tbXwtOWXX93H6bUS4HRGmDUzJAEomiFZM4VsCsVBpupcmTDr6LSfNTLPdT5Og8ZzsuRjXl6TAO8YPi2MBAclQOLUZYPtFhHKLcBg7Aea0LZeLVnQXyQGcwrHVtMgAkYEYZjjPN4M6NY69s2qaPbfjRFYVS0PMU_iR42e3mQVp0wl8vyXu8fRNReL3LKWuwVrSn_m4DDrGu8Wbu-sYIXny-GolEbMv94orpMt7o9Hr5ddFx7hkh9QcZG-25fLxIo1n7qrasLSCyGlToE6-BL-Md3va6Bv_cqAtcneGj7SLOhr6aWwVUauu-jg5d2Z01S37P8eQR8LlZ6bvkoPaoKEGFzeNy2qYDq8UZGVVP2v6LSpzWGPl93Otjintm_t62_JM3AkExD09PgLN1_uF9xsRvg80sEml8kYBOPiRTfmmNdSv-K8cu8oTcjMR0fEu8AYp8ECBo9dqz7PLcFFxUHAC-wQdwshjt-4Z_XK8RD6xtVZBbJjulgqMkIrnKxucGWppsZr7ADT6A7SvbPk4j_u5VBKJragkYWP4dL9Q0LYkY1cGPOTPpN5VMC5NA3Bxs72-w2wsnH7OIv67OQSXKQV6_2C_34"
    });
    cookies.add({
      "k": "refresh_token_develop",
      "v":
          "def50200c7eb4ae3c8aa947effa3dd36df1d2a7397fd19eec7ddf32b3877354630e48e979059465f241be2da77bc4374940db7df0f0e077adb0f5418462984c4a7cefdc9845e65d349969f1ca028c098480e13ef6cac501df934c84ebad18e4eb64a012dfde9aebbc983050e6afb882fe9b593e54373868a0034fa0707475a97760e9ff1eb67403604846a130c39a4cfe19e1633e85a92f5f14a623ed803d2cbbcc3e777652506e656e670671443a19188c36ae8f9c2c299f4f847e5a4b5400223176a3b44ea90b0f37f44ff6db7db01bc22fea2b6a379614452bb6300e80a8d9596248e977156b5516db0285ed4b9be794486290e2bdd9d4faca7d59bdcccc1b653c495c5a12e5da377125f85f7a8f7585c61b410ea68a5efe7d276b52f1a16c62856da3c364b81415a9a910856c3d4d4ca0827a2f98ec203ebb877e761a608138f684b2d1f74d7920918d6665dddb478f34539d48198b1bec7add7c53303f7fede13c94d139623896c"
    });
    return new Center(
      child: new RaisedButton(
        child: new Text('打开'),
        onPressed: () {
          Navigator.push(
            context,
            new MaterialPageRoute(
              builder: (context) => new YinWebViewPlugin(
                    url: url,
                    actions: <Widget>[
                      IconButton(
                        icon: Icon(Icons.alarm),
                        tooltip: "Alarm",
                        onPressed: () {
                          print("Alarm");
                        },
                      ),
                      PopupMenuButton(
                        itemBuilder: (BuildContext context) =>
                        <PopupMenuItem<String>>[
                          PopupMenuItem<String>(child: Text("热度"), value: "hot",),
                          PopupMenuItem<String>(child: Text("最新"), value: "new",),
                        ],
                        onSelected: (String action) {
                          switch (action) {
                            case "hot":
                              print("hot");
                              break;
                            case "new":
                              print("new");
                              break;
                          }
                        },
                        onCanceled: () {
                          print("onCanceled");
                        },
                      )
                    ],
                    scrollBar: false,
                    withLocalStorage: true,
//                    cookieList: cookies,
                    loadUrl: (value) {
                      print('test url=$value');
                    },
                    plugin: (YinWebview bean) {
                      if (bean != null) {
                        bean.getCookies(url, (value) {
                          print('test cookies=$value');
                        });
                      }
                    },
                  ),
            ),
          );
        },
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return new Scaffold(
      body: contentView(),
    );
  }

  @override
  void initState() {
    super.initState();
  }
}

==> yin_webview-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:yin_webview/YinWebViewPlugin.dart';

import 'package:yin_webview/yin_webview.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Webview',
      theme: new ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: new MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => new _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  String url = "https://m.debug.8591.com.hk/mall/detail/4000553";

  ///内容视图
  Widget contentView() {
    List<Map<String, String>> cookies = new List();
    cookies.add({"k": "hkroles_develop", "v": "buyer%2Cseller%2Ccardseller"});
    cookies.add({"k": "hkuid_develop", "v": "1010004"});

    return new Center(
      child: new RaisedButton(
        child: new Text('打开'),
        onPressed: () {
          Navigator.push(
            context,
            new MaterialPageRoute(
              builder: (context) => new YinWebViewPlugin(
                    url: url,
                    actions: <Widget>[
                      IconButton(
                        icon: Icon(Icons.alarm),
                        tooltip: "Alarm",
                        onPressed: () {
                          print("Alarm");
                        },
                      ),
                      PopupMenuButton(
                        itemBuilder: (BuildContext context) =>
                        <PopupMenuItem<String>>[
                          PopupMenuItem<String>(child: Text("热度"), value: "hot",),
                          PopupMenuItem<String>(child: Text("最新"), value: "new",),
                        ],
                        onSelected: (String action) {
                          switch (action) {
                            case "hot":
                              print("hot");
                              break;
                            case "new":
                              print("new");
                              break;
                          }
                        },
                        onCanceled: () {
                          print("onCanceled");
                        },
                      )
                    ],
                    scrollBar: false,
                    cookieList: cookies,
                    loadUrl: (value) {
                      print('test url=$value');
                    },
                    plugin: (YinWebview bean) {
                      if (bean != null) {
                        bean.getCookies(url, (value) {
                          print('test cookies=$value');
                        });
                      }
                    },
                  ),
            ),
          );
        },
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return new Scaffold(
      body: contentView(),
    );
  }

  @override
  void initState() {
    super.initState();
  }
}
